@@ -33,7 +33,19 @@
 //
 //-=============================================================================
 
-
+#if defined(__APPLE__)
+#include <array>
+#include <vector>
+#include <string>
+#include <memory>
+#include <map>
+#include <unistd.h>
+#include <sys/types.h>
+#include <sys/sysctl.h>
+#include <sys/proc_info.h>
+#include <sys/resource.h>
+#include <libproc.h>
+#endif
 
 #include "CheckProcessUtil.h"
 
@@ -62,6 +74,161 @@
 typedef LONG (WINAPI *TNtQueryInformationProcess)(HANDLE,UINT,PVOID,ULONG,PULONG);
 #endif
 
+#if defined(__APPLE__)
+/**
+ * This is a helper function only for macOS which digs into the bowels of macOS
+ * and extracts the command line for every process that was started by the
+ * current user.
+ *
+ * I have copied this code from the famous htop project. You can find its
+ * source code at https://github.com/htop-dev/htop.git
+ * The function that I copied is DarwinProcess_updateCmdLine in file
+ * darwin/DarwinProcess.c.
+ * The only modifications that I made is to C++14-ify it.
+ * @param pid: A processes' ID (PID) for which one wants to know the command
+ *             line.
+ * @return: The command line for the input PID or an empty string.
+ */
+static const std::string get_macOS_cmdline(const pid_t pid)
+{
+    std::string cmdline;
+
+    /* This function is from the old Mac version of htop. Originally from ps? */
+
+    /* Allocate space for the arguments. */
+    // The current macOS 12.4 kernel reserves 1048576 bytes for the arguments.
+    constexpr std::size_t argmax{1048576};
+    std::unique_ptr< std::array< char, argmax > > procargs{
+        new std::array< char, argmax >};
+
+    /*
+    * Make a sysctl() call to get the raw argument space of the process.
+    * The layout is documented in start.s, which is part of the Csu
+    * project.  In summary, it looks like:
+    *
+    * /---------------\ 0x00000000
+    * :               :
+    * :               :
+    * |---------------|
+    * | argc          |
+    * |---------------|
+    * | arg[0]        |
+    * |---------------|
+    * :               :
+    * :               :
+    * |---------------|
+    * | arg[argc - 1] |
+    * |---------------|
+    * | 0             |
+    * |---------------|
+    * | env[0]        |
+    * |---------------|
+    * :               :
+    * :               :
+    * |---------------|
+    * | env[n]        |
+    * |---------------|
+    * | 0             |
+    * |---------------| <-- Beginning of data returned by sysctl() is here.
+    * | argc          |
+    * |---------------|
+    * | exec_path     |
+    * |:::::::::::::::|
+    * |               |
+    * | String area.  |
+    * |               |
+    * |---------------| <-- Top of stack.
+    * :               :
+    * :               :
+    * \---------------/ 0xffffffff
+    */
+    int mib[3]{CTL_KERN, KERN_PROCARGS2, pid};
+    std::size_t size{static_cast< size_t >(argmax)};
+    if(sysctl(mib, 3, procargs->data(), &size, NULL, 0 ) == - 1)
+    {
+        // Sorry, but the info for this PID cannot be retrieved, because the
+        // process is not owned by the current user.
+        std::cerr << "Not owner of PID " << pid << "\n";
+        return cmdline;
+    }
+
+    int nargs;
+    std::memcpy(&nargs, procargs->data(), sizeof(nargs));
+    char* cp{procargs->data() + sizeof(nargs)};
+
+    /* Skip the saved exec_path. */
+    for(; cp < &((*procargs)[size]); ++cp)
+    {
+        if(*cp == '\0')
+        {
+            /* End of exec_path reached. */
+            break;
+        }
+    }
+
+    if(cp == &((*procargs)[size]))
+    {
+        // The end of the memory where the procargs are stored have been
+        // reached. Sorry but this is it and it is time to leave.
+        return cmdline;
+    }
+
+    /* Skip trailing '\0' characters. */
+    for (; cp < &((*procargs)[size]); ++cp)
+    {
+        if(*cp != '\0')
+        {
+            /* Beginning of first argument reached. */
+            break;
+        }
+    }
+
+    if(cp == &((*procargs)[size]))
+    {
+        // The end of the memory where the procargs are stored have been
+        // reached. Sorry but this is it and it is time to leave.
+        return cmdline;
+    }
+
+    /* Save where the argv[0] string starts. */
+    char* sp{cp}, *np{nullptr};
+    int end;
+    for(int c{0}; (c < nargs) && (cp < &((*procargs)[size])); ++cp)
+    {
+        if(*cp == '\0')
+        {
+            c++;
+            if(np != nullptr)
+            {
+            /* Convert previous '\0'. */
+                *np = ' ';
+            }
+            /* Note location of current '\0'. */
+            np = cp;
+
+            if(end == 0)
+            {
+                end = cp - sp;
+            }
+        }
+    }
+
+    /*
+    * sp points to the beginning of the arguments/environment string, and
+    * np should point to the '\0' terminator for the string.
+    */
+    if(np == nullptr || np == sp)
+    {
+        /* Empty or unterminated string. */
+        return cmdline;
+    }
+
+    cmdline = sp;
+
+    return cmdline;
+}
+#endif
+
 namespace Starter_ns {
 //=============================================================
 //=============================================================
@@ -497,6 +664,98 @@ namespace Starter_ns {
             delete i;
         proc_list.clear();
 
+#if defined(__APPLE__)
+        // Collect a list of all PIDs thats the current user is able to control
+        // and store them in a std::map. The PID is the key and a bunch of
+        // information is stored in the value as a std::tuple.
+        // Assume that macOS cannot run more than 65535 processes at the same
+        // time. But verify this against the rlimits.
+        struct rlimit max_proc_limits{};
+        // I do not check the return value because there is nothing that can be
+        // done about a failed getrlimni call. This will only mean that the
+        // assumption about the maximum number of concurrently running processes
+        // cannot be verified.
+        getrlimit(RLIMIT_NPROC, &max_proc_limits);
+        constexpr std::size_t assumed_max_proc_limit{65535};
+        if(max_proc_limits.rlim_max > assumed_max_proc_limit)
+        {
+            TANGO_LOG_INFO << "This code assumes that macOS cannot run more than "
+            << assumed_max_proc_limit
+            << " processes at the same time. The verification that this "
+            << "has failed though. macOS has reported that it can run "
+            << max_proc_limits.rlim_max
+            << " processes at the same time. What does this mean? This means "
+            << "that this program will continue to run without any further "
+            << "notification. But there is now a non-negligible chance that "
+            << "this program will not be able to control all Tango Controls "
+            << "processes. What can you do about this? Please open an issue at "
+            << "https://gitlab.com/tango-controls/starter and add this "
+            << "message. The cppTango developers will address this issue as "
+            << "soon as possible.";
+        }
+        std::array< pid_t, assumed_max_proc_limit > temp_pids{};
+        std::size_t number_of_processes;
+        const auto uid{getuid()};
+        if(uid != 0)
+        {
+            // Not root. Get only the PIDs that the user's group can control.
+            number_of_processes = static_cast< std::size_t >(proc_listpids(PROC_UID_ONLY, static_cast< uint32_t > (uid), &temp_pids, temp_pids.size() * sizeof(pid_t))) / sizeof(pid_t);
+        }
+        else
+        {
+            // This is the root user who can control every process. Therfore
+            // get a list of all processes.
+            number_of_processes = static_cast< std::size_t >(
+                proc_listallpids(&temp_pids, temp_pids.size() * sizeof(pid_t)));
+        }
+
+        std::vector< pid_t > pids{temp_pids.begin(), temp_pids.end()};
+        pids.resize(number_of_processes);
+        std::map < pid_t, std::tuple< const std::string, const std::string,
+            const struct proc_taskallinfo > > process_info_map;
+        for (const auto& pid: pids)
+        {
+            std::array< uint8_t, PROC_PIDPATHINFO_MAXSIZE > proc_path{};
+            const ssize_t proc_path_size{
+                proc_pidpath(pid, &proc_path, PROC_PIDPATHINFO_MAXSIZE)};
+            std::string path{proc_path.begin(), proc_path.end()};
+            path.resize(proc_path_size);
+
+            struct proc_taskallinfo proc_info{};
+            const std::string cmdline{get_macOS_cmdline(pid)};
+            // An empty command line means that this user does not have access
+            // to the program's information.
+            if(cmdline.empty() == false)
+            {
+                process_info_map.emplace(
+                    pid, std::make_tuple(path, cmdline, proc_info));
+            }
+            else
+            {
+                TANGO_LOG_INFO << "Function manageProcFiles cannot retrieve "
+                    "the command line for pid "
+                    << pid
+                    << "\n";
+            }
+        }
+
+        for(const auto& info: process_info_map)
+        {
+            const pid_t pid {info.first};
+            const std::string path{std::get< 0 >(info.second)};
+            const std::string cmdline{std::get< 1 >(info.second)};
+            const struct proc_taskallinfo proc_info{std::get< 2 >(info.second)};
+            const std::string comm{proc_info.pbsd.pbi_comm};
+            const std::string name{proc_info.pbsd.pbi_name};
+
+            // Get PID
+            auto* process{new Process};
+            process->pid = pid;
+            process->line = cmdline;
+            // Add process object to std::vector
+            proc_list.push_back(process);
+        }
+#else
         //	build processes list
         DIR *proc = opendir("/proc");
         if (proc == nullptr) {
@@ -559,6 +818,7 @@ namespace Starter_ns {
             }
         }
         closedir(proc);
+#endif
     }
 
 
@@ -567,8 +827,9 @@ namespace Starter_ns {
  *	Manage the /proc files
  */
 //=============================================================
+#if !defined(__APPLE__)
     bool ProcessData::manageProcFiles(Process *process) {
-#if (defined __GLIBC__) || (defined __darwin__) || (defined __freebsd__)
+#if (defined __GLIBC__) || (defined __linux__) || (defined __freebsd__)
 
         //	Read command line file
         TangoSys_OMemStream fname;
@@ -693,7 +954,7 @@ namespace Starter_ns {
         return true;
 #endif
     }
-
+#endif //#if !defined(__APPLE__)
 #endif    //	_TG_WINDOWS_
 
 
