@@ -38,9 +38,10 @@
 //
 //-============================================================================
 
-
 #include "anyoption.h"
 
+using namespace std;
+
 AnyOption::AnyOption()
 {
 	init();
@@ -1003,13 +1004,15 @@ AnyOption::consumeFile( char *buffer )
        	for( unsigned int i = 0 ; i < strlen( buffer ) ; i++ ){
        	if( *cursor == endofline ) { /* end of line */
           	if( pline != NULL ) /* valid line */
+            {
                		processLine( pline, linelength );
                  	pline = NULL;
                  	newline = true;
+            }
            	}else if( newline ){ /* start of line */
                  	newline = false;
               		if( (*cursor != comment ) ){ /* not a comment */
-		    		pline = cursor ;
+                        pline = cursor ;
                     		linelength = 0 ;
                 	}
              	}
