@@ -30,18 +30,20 @@
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-// 
+//
 // Tango is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
 //-============================================================================
 
 #include <iostream>
+#include <string>
+#include <cmath>
 #include <anyoption.h>
 #include <tango/tango.h>
 
@@ -52,13 +54,10 @@
 
 #include <stdlib.h>
 
-using namespace std;
-
-
 int ping_database(int);
-int check_device(char *);
+int check_device(const char *);
 int add_server(char *,char *,char *);
-void list2vect(string &,vector<string> &);
+void list2vect(std::string &,std::vector<std::string> &);
 int check_server(char *);
 int server_list();
 int server_instance_list(char *);
@@ -68,13 +67,126 @@ int delete_property(char *,char *);
 int ping_network(int,bool);
 int check_net(bool);
 int tac_enabled(void);
-int ping_device(char *,int);
-int check_dev(char *);
+int ping_device(const std::string &, double);
+int check_dev(const char *);
 
+// The min and max allowed timeouts. Used by the function
+// compute_loops_and_sleep_time.
+static constexpr double MIN_TIMEOUT{0.001};
+static constexpr double MAX_TIMEOUT{1200.0};
+
+static void printUsageAndExit(const std::unique_ptr<AnyOption>& opt)
+{
+  opt->printUsage();
+  exit(-EINVAL);
+}
+
+// method: compute_loops_and_sleep_time
+//
+// descritpion: Compute the number of loops and the sleep time between loop
+//              iterations.
+// input parameters:
+//  - timeout_in_s: Total duration in seconds for all loop iterations combined.
+// output parameters:
+//  - number_of_loops: Number of times a loop needs to run to reach a total
+// run time duration of timeout_in_s with sleeps of sleep_time seconds between
+// iteratons.
+// - sleep_time: Time to sleep with nanosleep between loop iterations.
+// return: -ERANGE if the timeout_in_s parameter does not fall within the
+// expected range.
+static int compute_loops_and_sleep_time(double timeout_in_s, unsigned int& number_of_loops, struct timespec& sleep_time)
+{
+    if((timeout_in_s < MIN_TIMEOUT) || (timeout_in_s > MAX_TIMEOUT))
+    {
+      std::cerr << "Error: The given timeout ("
+                << timeout_in_s
+                << ") does not fall in the allowed range of ["
+                << MIN_TIMEOUT
+                << ", "
+                << MAX_TIMEOUT
+                << "].\n";
+        return -ERANGE;
+    }
+
+    if(timeout_in_s <= 0.01)
+    {
+        number_of_loops = 2;
+        sleep_time.tv_sec = 0;
+        sleep_time.tv_nsec = (timeout_in_s / number_of_loops * 1e9);
+    }
+    else if(timeout_in_s <= 0.1)
+    {
+        number_of_loops = 20;
+        sleep_time.tv_sec = 0;
+        sleep_time.tv_nsec = (timeout_in_s / number_of_loops * 1e9);
+    }
+    else if(timeout_in_s <= 1.0)
+    {
+        number_of_loops = 200;
+        sleep_time.tv_sec = 0;
+        sleep_time.tv_nsec = (timeout_in_s / number_of_loops * 1e9);
+    }
+    else
+    {
+        sleep_time.tv_sec = 0;
+        sleep_time.tv_nsec = 0.5 * 1e9;
+        number_of_loops = timeout_in_s / 0.5;
+    }
+
+    return 0;
+}
+
+// method: convert_string_to_double
+//
+// descritpion: Convert a std::string to a double. The input is checked to be valid.
+// input parameters:
+//  - value_string: String representation of a double
+// output parameters:
+//  - value: The value represented by a double
+// return: -ERANGE if the timeout_in_s parameter does not fall within the
+// expected range.
+static int convert_string_to_double(const std::string& value_as_string,
+    double& value)
+{
+    int ret{};
+    try
+    {
+        auto converted_value{std::stod(value_as_string)};
+        if(!std::isnan(converted_value))
+        {
+            // The value is within range, everything is OK.
+            value = converted_value;
+        }
+        else
+        {
+            std::cout << "The parameter's value ("
+                << value_as_string
+                << ") cannot be \"Not a Number\" (NaN).\n";
+            ret = -EDOM;
+        }
+    }
+    catch(std::invalid_argument& ex)
+    {
+        std::cout << "The parameter's value ("
+            << value_as_string
+            << ") cannot be converted to a numerical value.\n";
+        ret = -EINVAL;
+    }
+    catch(std::out_of_range& ex)
+    {
+        std::cout << "The parameter's value ("
+            << value_as_string
+            << ") cannot be converted to a numerical value that lies within "
+                "the value range of the used data type (double).\n";
+        ret = -ERANGE;
+    }
+
+    return ret;
+}
 
 int main(int argc,char *argv[])
 {
-	AnyOption *opt = new AnyOption();
+	auto opt{std::make_unique< AnyOption >()};
 
 //
 // Add usage menu
@@ -122,9 +234,7 @@ int main(int argc,char *argv[])
 
 	if (!opt->hasOptions())
 	{
-		opt->printUsage();
-		delete opt;
-		return 0;
+		printUsageAndExit(opt);
 	}
 
 //
@@ -133,9 +243,7 @@ int main(int argc,char *argv[])
 
 	if (opt->getFlag("help") || opt->getFlag('h'))
 	{
-		opt->printUsage();
-		delete opt;
-		return 0;
+		printUsageAndExit(opt);
 	}
 
 //
@@ -155,27 +263,21 @@ int main(int argc,char *argv[])
 			opt->getFlag("ping-network") == true ||
 			opt->getFlag("tac-enabled") == true ||
 		    opt->getFlag("with-properties") == true)
-			cout << "Can't mix option --ping-database with other option(s)" << endl;
+			std::cerr << "Can't mix option --ping-database with other option(s)" << std::endl;
 
 		if (argc > 3)
 		{
-			cout << "Bad argument number for option --ping-database" << endl;
-			opt->printUsage();
-			delete opt;
-			return 0;
+			std::cerr << "Bad argument number for option --ping-database" << std::endl;
+      printUsageAndExit(opt);
 		}
 
-		int ret;
 		if (argc == 2)
-			ret = ping_database(0);
+			return ping_database(0);
 		else
 		{
 			int sec = atoi(argv[2]);
-			ret = ping_database(sec);
+			return ping_database(sec);
 		}
-
-		delete opt;
-		return ret;
 	}
 
 //
@@ -195,22 +297,16 @@ int main(int argc,char *argv[])
 			opt->getFlag("ping-network") == true ||
 			opt->getFlag("tac-enabled") == true ||
 		    opt->getFlag("with-properties") == true)
-			cout << "Can't mix option --add-server with other option(s)" << endl;
+			std::cerr << "Can't mix option --add-server with other option(s)" << std::endl;
 		else
 		{
 			if (argc != 3)
 			{
-				cout << "Bad argument number for option --check_device" << endl;
-				opt->printUsage();
-				delete opt;
-				return 0;
+				std::cerr << "Bad argument number for option --check_device" << std::endl;
+        printUsageAndExit(opt);
 			}
 
-			int ret;
-			ret = check_device(opt->getValue("check-device"));
-
-			delete opt;
-			return ret;
+			return check_device(opt->getValue("check-device"));
 		}
 	}
 
@@ -231,22 +327,16 @@ int main(int argc,char *argv[])
 			opt->getFlag("ping-network") == true ||
 			opt->getFlag("tac-enabled") == true ||
 		    opt->getFlag("with-properties") == true)
-			cout << "Can't mix option --add-server with other option(s)" << endl;
+			std::cerr << "Can't mix option --add-server with other option(s)" << std::endl;
 		else
 		{
 			if (argc != 5)
 			{
-				cout << "Bad argument number for option --add-server" << endl;
-				opt->printUsage();
-				delete opt;
-				return 0;
+				std::cerr << "Bad argument number for option --add-server" << std::endl;
+				printUsageAndExit(opt);
 			}
 
-			int ret;
-			ret = add_server(opt->getValue("add-server"),opt->getArgv(0),opt->getArgv(1));
-
-			delete opt;
-			return ret;
+			return add_server(opt->getValue("add-server"),opt->getArgv(0),opt->getArgv(1));
 		}
 	}
 
@@ -267,22 +357,16 @@ int main(int argc,char *argv[])
 			opt->getFlag("ping-network") == true ||
 			opt->getFlag("tac-enabled") == true ||
 		    opt->getFlag("with-properties") == true)
-			cout << "Can't mix option --check-server with other option(s)" << endl;
+			std::cerr << "Can't mix option --check-server with other option(s)" << std::endl;
 		else
 		{
 			if (argc != 3)
 			{
-				cout << "Bad argument number for option --check_server" << endl;
-				opt->printUsage();
-				delete opt;
-				return 0;
+				std::cerr << "Bad argument number for option --check_server" << std::endl;
+        printUsageAndExit(opt);
 			}
 
-			int ret;
-			ret = check_server(opt->getValue("check-server"));
-
-			delete opt;
-			return ret;
+			return check_server(opt->getValue("check-server"));
 		}
 	}
 
@@ -302,22 +386,16 @@ int main(int argc,char *argv[])
 			opt->getFlag("ping-network") == true ||
 			opt->getFlag("tac-enabled") == true ||
 		    opt->getFlag("with-properties") == true)
-			cout << "Can't mix option --server-list with other option(s)" << endl;
+			std::cerr << "Can't mix option --server-list with other option(s)" << std::endl;
 		else
 		{
 			if (argc != 2)
 			{
-				cout << "Bad argument number for option --server-list" << endl;
-				opt->printUsage();
-				delete opt;
-				return 0;
+				std::cerr << "Bad argument number for option --server-list" << std::endl;
+        printUsageAndExit(opt);
 			}
 
-			int ret;
-			ret = server_list();
-
-			delete opt;
-			return ret;
+			return server_list();
 		}
 	}
 
@@ -337,22 +415,16 @@ int main(int argc,char *argv[])
 			opt->getFlag("ping-network") == true ||
 			opt->getFlag("tac-enabled") == true ||
 		    opt->getFlag("with-properties") == true)
-			cout << "Can't mix option --server-instance-list with other option(s)" << endl;
+			std::cerr << "Can't mix option --server-instance-list with other option(s)" << std::endl;
 		else
 		{
 			if (argc != 3)
 			{
-				cout << "Bad argument number for option --server-instance-list" << endl;
-				opt->printUsage();
-				delete opt;
-				return 0;
+				std::cerr << "Bad argument number for option --server-instance-list" << std::endl;
+        printUsageAndExit(opt);
 			}
 
-			int ret;
-			ret = server_instance_list(opt->getValue("server-instance-list"));
-
-			delete opt;
-			return ret;
+			return server_instance_list(opt->getValue("server-instance-list"));
 		}
 	}
 
@@ -371,27 +443,21 @@ int main(int argc,char *argv[])
 			opt->getFlag("ping-network") == true ||
 			opt->getFlag("tac-enabled") == true ||
 		    opt->getValue("delete-property") != NULL)
-			cout << "Can't mix option --delete-server with other option(s)" << endl;
+			std::cerr << "Can't mix option --delete-server with other option(s)" << std::endl;
 		else
 		{
 			if ((argc < 3 || argc > 4) ||
 				(argc == 3 && strcmp(argv[2],"--with-properties") == 0) ||
 				(strcmp(opt->getValue("delete-server"),"--with-properties") == 0))
 			{
-				cout << "Bad option delete-server usage" << endl;
-				opt->printUsage();
-				delete opt;
-				return 0;
+				std::cerr << "Bad option delete-server usage" << std::endl;
+        printUsageAndExit(opt);
 			}
 
-			int ret;
 			if (opt->getFlag("with-properties") == true)
-				ret = delete_server(opt->getValue("delete-server"),true);
+				return delete_server(opt->getValue("delete-server"),true);
 			else
-				ret = delete_server(opt->getValue("delete-server"),false);
-
-			delete opt;
-			return ret;
+				return  delete_server(opt->getValue("delete-server"),false);
 		}
 	}
 
@@ -412,22 +478,16 @@ int main(int argc,char *argv[])
 			opt->getFlag("tac-enabled") == true ||
 			opt->getFlag("ping-network") == true ||
 			opt->getFlag("ping-database") == true)
-			cout << "Can't mix option --add-property with other option(s)" << endl;
+			std::cerr << "Can't mix option --add-property with other option(s)" << std::endl;
 		else
 		{
 			if (argc != 5)
 			{
-				cout << "Bag argument number for option --add-property" << endl;
-				opt->printUsage();
-				delete opt;
-				return 0;
+				std::cerr << "Bad argument number for option --add-property" << std::endl;
+        printUsageAndExit(opt);
 			}
 
-			int ret;
-			ret = add_property(opt->getValue("add-property"),opt->getArgv(0),opt->getArgv(1));
-
-			delete opt;
-			return ret;
+			return add_property(opt->getValue("add-property"),opt->getArgv(0),opt->getArgv(1));
 		}
 	}
 
@@ -448,22 +508,16 @@ int main(int argc,char *argv[])
 			opt->getFlag("ping-network") == true ||
 			opt->getFlag("tac-enabled") == true ||
 			opt->getFlag("ping-database") == true)
-			cout << "Can't mix option --delete-property with other option(s)" << endl;
+			std::cerr << "Can't mix option --delete-property with other option(s)" << std::endl;
 		else
 		{
 			if (argc != 4)
 			{
-				cout << "Bag argument number for option --add-property" << endl;
-				opt->printUsage();
-				delete opt;
-				return 0;
+				std::cerr << "Bad argument number for option --add-property" << std::endl;
+        printUsageAndExit(opt);
 			}
 
-			int ret;
-			ret = delete_property(opt->getValue("delete-property"),opt->getArgv(0));
-
-			delete opt;
-			return ret;
+			return delete_property(opt->getValue("delete-property"),opt->getArgv(0));
 		}
 	}
 
@@ -474,7 +528,7 @@ int main(int argc,char *argv[])
 	if (opt->getFlag("ping-network") == true)
 	{
 		bool verbose = false;
-		
+
 		if (opt->getValue("add-server") != NULL ||
 			opt->getValue("delete-server") != NULL ||
 		    opt->getValue("add-property") != NULL ||
@@ -486,23 +540,19 @@ int main(int argc,char *argv[])
 			opt->getFlag("ping-database") == true ||
 			opt->getFlag("tac-enabled") == true ||
 		    opt->getFlag("with-properties") == true)
-			cout << "Can't mix option --ping-network with other option(s)" << endl;
+			std::cerr << "Can't mix option --ping-network with other option(s)" << std::endl;
 
 		if (argc > 4)
 		{
-			cout << "Bad argument number for option --ping-network" << endl;
-			opt->printUsage();
-			delete opt;
-			return 0;
+			std::cerr << "Bad argument number for option --ping-network" << std::endl;
+      printUsageAndExit(opt);
 		}
 		else if (argc == 4)
 		{
 			if (strcmp(argv[3],"-v") != 0)
 			{
-				cout << "Bad argument for option --ping-network" << endl;
-				opt->printUsage();
-				delete opt;
-				return 0;
+				std::cerr << "Bad argument for option --ping-network" << std::endl;
+        printUsageAndExit(opt);
 			}
 			else
 				verbose = true;
@@ -514,26 +564,20 @@ int main(int argc,char *argv[])
 				verbose = true;
 			}
 		}
-		
-		int ret;
+
 		if (argc == 2)
-			ret = ping_network(0,verbose);
+			return ping_network(0,verbose);
 		else
 		{
 			int sec = 0;
 			sec = atoi(argv[2]);
 			if ((verbose == false) && (sec == 0))
 			{
-				cout << "Bad argument for option --ping-network" << endl;
-				opt->printUsage();
-				delete opt;
-				return 0;
+				std::cerr << "Bad argument for option --ping-network" << std::endl;
+        printUsageAndExit(opt);
 			}
-			ret = ping_network(sec,verbose);
+			return ping_network(sec,verbose);
 		}
-
-		delete opt;
-		return ret;
 	}
 
 //
@@ -552,22 +596,16 @@ int main(int argc,char *argv[])
 			opt->getFlag("server-list") == true ||
 			opt->getFlag("ping-network") == true ||
 		    opt->getFlag("with-properties") == true)
-			cout << "Can't mix option --tac-enabled with other option(s)" << endl;
+			std::cerr << "Can't mix option --tac-enabled with other option(s)" << std::endl;
 
 		if (argc > 2)
 		{
-			cout << "Bad argument number for option --tac-enabled" << endl;
-			opt->printUsage();
-			delete opt;
-			return 0;
+			std::cerr << "Bad argument number for option --tac-enabled" << std::endl;
+      printUsageAndExit(opt);
 		}
 
-		int ret;
-		ret = tac_enabled();
-
-		delete opt;
-		return ret;
-	}
+		return tac_enabled();
+    }
 
 //
 // --ping-device option
@@ -586,29 +624,30 @@ int main(int argc,char *argv[])
 			opt->getFlag("ping-network") == true ||
 			opt->getFlag("tac-enabled") == true ||
 		    opt->getFlag("with-properties") == true)
-			cout << "Can't mix option --ping-device with other option(s)" << endl;
+			std::cerr << "Can't mix option --ping-device with other option(s)" << std::endl;
 		else
 		{
-			int ret;
-			int sec = 0;
-
-			if (argc < 3 || argc > 4)
+			if (argc == 3)
 			{
-				cout << "Bad argument number for option --ping_device" << endl;
-				opt->printUsage();
-				delete opt;
-				return 0;
-			}
-			else if (argc == 4)
-			{
-				sec = atoi(argv[3]);
-			}
-
-			ret = ping_device(opt->getValue("ping-device"),sec);
-
-			delete opt;
-			return ret;
-		}
+                double timeout{};
+                const int ret{convert_string_to_double(argv[2], timeout)};
+                if(ret == 0)
+                {
+                    return ping_device(opt->getValue("ping-device"), timeout);
+                }
+                else
+                {
+                    std::cerr << "Illegal parameter provided. Please try "
+                    "again!\n";
+                    return -ret;
+                }
+            }
+            else
+            {
+                std::cerr << "Bad argument number for option --ping_device" << std::endl;
+                printUsageAndExit(opt);
+            }
+        }
 	}
 
 //
@@ -617,17 +656,17 @@ int main(int argc,char *argv[])
 
 	else
 	{
-		cout << "Wrong usage" << endl;
-		opt->printUsage();
+		std::cerr << "Wrong usage" << std::endl;
+		printUsageAndExit(opt);
 	}
 
-	delete opt;
+    return -ENOTSUP;
 }
 
 //+-------------------------------------------------------------------------
 //
 // method : 		ping_database
-// 
+//
 // description : 	This function connect to the database and executes
 //					one of its command in order to check the database
 //					connectivity.
@@ -640,8 +679,6 @@ int main(int argc,char *argv[])
 
 int ping_database(int nb_sec)
 {
-	int ret = 0;
-
 	setenv("SUPER_TANGO","true",1);
 
 	int nb_loop;
@@ -665,7 +702,7 @@ int ping_database(int nb_sec)
 //
 // First sleep for 1 sec before trying to access the db
 // This was needed when ported to Natty (Ubuntu 11.04) in the
-// tango-db startup script. Db process did not start if tango 
+// tango-db startup script. Db process did not start if tango
 // admin starts pinging db device too early !!
 //
 
@@ -690,14 +727,13 @@ int ping_database(int nb_sec)
 		{
 			Tango::Database db;
 
-			string db_info;
+			std::string db_info;
 			db_info = db.get_info();
-			ret = 0;
-			nb_loop = 0;
+
+      return 0;
 		}
 		catch (Tango::DevFailed &e)
 		{
-			ret = -1;
 			if (infinite == false)
 				--nb_loop;
 		}
@@ -706,13 +742,13 @@ int ping_database(int nb_sec)
 			nanosleep(&ts,NULL);
 	}
 
-	return ret;	
+	return -1;
 }
 
 //+-------------------------------------------------------------------------
 //
 // method : 		check_device
-// 
+//
 // description : 	This function checks if a device is defined in the DB
 //
 // argument : in : 	- name : The device name
@@ -721,28 +757,27 @@ int ping_database(int nb_sec)
 //
 //--------------------------------------------------------------------------
 
-int check_device(char *name)
+int check_device(const char *name)
 {
-	int ret = 0;
-
 	try
 	{
 		Tango::Database db;
 
-		string d_name(name);
+		std::string d_name(name);
 		Tango::DbDevImportInfo dii = db.import_device(d_name);
 	}
 	catch (Tango::DevFailed &e)
 	{
-		ret = -1;
+    return -1;
 	}
-	return ret;	
+
+  return 0;
 }
 
 //+-------------------------------------------------------------------------
 //
 // method : 		add_server
-// 
+//
 // description : 	This function adds a server definition in the DB
 //
 // argument : in : 	- d_name : The device server name (exec/inst)
@@ -755,81 +790,56 @@ int check_device(char *name)
 
 int add_server(char *d_name,char *c_name,char *d_list)
 {
-	int ret = 0;
-
 //
 // Check ds name syntax
 //
 
-	string ds_name(d_name);
-	string::size_type pos;
+std::string ds_name(d_name);
+	std::string::size_type pos;
 
 	pos = ds_name.find('/');
-#ifdef  __SUNPRO_CC
-	int n1 = 0;
-	count(ds_name.begin(),ds_name.end(),'/',n1);
-	if ((n1 != 1) || pos == 0 || pos == (ds_name.size() - 1))
-	{
-#else
 	if ((count(ds_name.begin(),ds_name.end(),'/') != 1) || pos == 0 || pos == (ds_name.size() - 1))
 	{
-#endif
-		cout << "Wrong syntax for ds name" << endl;
-		ret = -1;
-		return ret;
+		std::cerr << "Wrong syntax for ds name" << std::endl;
+    	return -1;
 	}
 
 //
 // Check class name syntax
 //
 
-	string class_name(c_name);
-#ifdef  __SUNPRO_CC
-	count(class_name.begin(),class_name.end(),'/',n1);
-	if (n1 != 0)
-	{
-#else	
+	std::string class_name(c_name);
 	if (count(class_name.begin(),class_name.end(),'/') != 0)
 	{
-#endif
-		cout << "Wrong syntax for class name" << endl;
-		ret = -1;
-		return ret;
+		std::cerr << "Wrong syntax for class name" << std::endl;
+		return -1;
 	}
 
 //
 // Check device list and device syntax
 //
 
-	string dev_list(d_list);
-	vector<string> dev_names;
+	std::string dev_list(d_list);
+	std::vector<std::string> dev_names;
 
 	list2vect(dev_list,dev_names);
 
 	for (unsigned int loop = 0;loop < dev_names.size();++loop)
 	{
-#ifdef  __SUNPRO_CC
-		count(dev_names[loop].begin(),dev_names[loop].end(),'/',n1);
-		if (n1 != 2)
-		{
-#else	
 		if (count(dev_names[loop].begin(),dev_names[loop].end(),'/') != 2)
 		{
-#endif
-			cout << "Wrong syntax for device " << dev_names[loop] << endl;
-			ret = -1;
-			return ret;
+			std::cerr << "Wrong syntax for device " << dev_names[loop] << std::endl;
+			return -1;
 		}
 
-		string::size_type pos1,pos2;
+		std::string::size_type pos1,pos2;
 		pos1 = dev_names[loop].find('/');
 		pos2 = dev_names[loop].rfind('/');
 
 		if (pos1 == 0 || pos2 == dev_names[loop].length() - 1 || pos2 == pos1 + 1)
 		{
-			cout << "Wrong syntax for device " << dev_names[loop] << endl;
-			ret = -1;
-			return ret;
+			std::cerr << "Wrong syntax for device " << dev_names[loop] << std::endl;
+      return -1;
 		}
 	}
 
@@ -864,15 +874,16 @@ int add_server(char *d_name,char *c_name,char *d_list)
 	}
 	catch (Tango::DevFailed &e)
 	{
-		ret = -1;
+    return -1;
 	}
-	return ret;
+
+	return 0;
 }
 
 //+-------------------------------------------------------------------------
 //
 // method : 		check_server
-// 
+//
 // description : 	This function checks if a device server is defined in the DB
 //
 // argument : in : 	- d_name : The device server name
@@ -883,22 +894,18 @@ int add_server(char *d_name,char *c_name,char *d_list)
 
 int check_server(char *d_name)
 {
-	int ret = 0;
-
-	string dev_name = "dserver/";
-	string ds_name = d_name;
+	std::string dev_name = "dserver/";
+	std::string ds_name = d_name;
 
 	dev_name = dev_name + ds_name;
 
-	ret = check_device((char *)dev_name.c_str());
-
-	return ret;
+	return check_device((char *)dev_name.c_str());
 }
 
 //+-------------------------------------------------------------------------
 //
 // method : 		server_list
-// 
+//
 // description : 	This function lists all server names
 //
 // The function returns 0 if at least one server is defined. Otherwise returns -1
@@ -907,32 +914,30 @@ int check_server(char *d_name)
 
 int server_list()
 {
-	int ret = 0;
-
-	try 
+	try
 	{
 		Tango::Database db;
 
-		vector<string> servers;
-		db.get_server_name_list() >> servers; 
-		for(int idx = 0; idx < servers.size(); ++idx)
+		std::vector<std::string> servers;
+		db.get_server_name_list() >> servers;
+		for(size_t idx = 0; idx < servers.size(); ++idx)
 		{
-			cout << servers[idx] << " ";
+			std::cout << servers[idx] << " ";
 		}
-		cout << endl;
+		std::cout << std::endl;
 	}
 	catch (Tango::DevFailed &e)
 	{
-		ret = -1;
+    return -1;
 	}
 
-	return ret;
+	return 0;
 }
 
 //+-------------------------------------------------------------------------
 //
 // method : 		server_instance_list
-// 
+//
 // description : 	This function lists all server instances for the given
 //                      server name
 //
@@ -944,36 +949,34 @@ int server_list()
 
 int server_instance_list(char *s_name)
 {
-	int ret = 0;
-
-	try 
+	try
 	{
 		Tango::Database db;
 
-		string server_name = s_name;
+		std::string server_name = s_name;
 		size_t start_pos = server_name.size() + 1;
 		server_name += "/*";
 
-		vector<string> servers;
-		db.get_server_list(server_name) >> servers; 
-		for(int idx = 0; idx < servers.size(); ++idx)
+		std::vector<std::string> servers;
+		db.get_server_list(server_name) >> servers;
+		for(size_t idx = 0; idx < servers.size(); ++idx)
 		{
-			cout << servers[idx].substr(start_pos) << " ";
+			std::cout << servers[idx].substr(start_pos) << " ";
 		}
-		cout << endl;
+		std::cout << std::endl;
 	}
 	catch (Tango::DevFailed &e)
 	{
-		ret = -1;
+    return -1;
 	}
 
-	return ret;
+	return 0;
 }
 
 //+-------------------------------------------------------------------------
 //
 // method : 		delete_server
-// 
+//
 // description : 	This function deletes a device server from the DB
 //
 // argument : in : 	- d_name : The device server name
@@ -985,36 +988,25 @@ int server_instance_list(char *s_name)
 
 int delete_server(char *d_name,bool with_res)
 {
-	int ret = 0;
-
-	string ds_name(d_name);
+	std::string ds_name(d_name);
 
 //
 // Check device server name syntax
 //
 
-	string::size_type pos;
+	std::string::size_type pos;
 	pos = ds_name.find('/');
-	
-#ifdef  __SUNPRO_CC
-	int n1 = 0;
-	count(ds_name.begin(),ds_name.end(),'/',n1);
-	if (pos == 0 || pos == ds_name.size() - 1 || n1 != 1)
-	{
-#else
+
 	if (pos == 0 || pos == ds_name.size() - 1 ||
 		count(ds_name.begin(),ds_name.end(),'/') != 1)
 	{
-#endif
-		ret = -1;
-		return ret;
+    return -1;
 	}
 
-	ret = check_server(d_name);
+	int ret = check_server(d_name);
 	if (ret != 0)
 		return ret;
 
-
 	try
 	{
 
@@ -1032,7 +1024,7 @@ int delete_server(char *d_name,bool with_res)
 //
 
 			Tango::DbDatum db_res = db.get_device_class_list(ds_name);
-			vector<string> dev_list;
+			std::vector<std::string> dev_list;
 			db_res >> dev_list;
 
 //
@@ -1041,7 +1033,7 @@ int delete_server(char *d_name,bool with_res)
 
 			for (unsigned int loop = 0;loop < dev_list.size();++loop)
 			{
-				vector<string> prop_list;
+				std::vector<std::string> prop_list;
 
 				db.get_device_property_list(dev_list[loop],"*",prop_list);
 
@@ -1052,7 +1044,7 @@ int delete_server(char *d_name,bool with_res)
 				if (prop_list.empty() == false)
 				{
 					Tango::DbData dbd;
-					
+
 					for (unsigned int ctr = 0;ctr < prop_list.size();++ctr)
 						dbd.push_back(Tango::DbDatum(prop_list[ctr]));
 
@@ -1060,7 +1052,7 @@ int delete_server(char *d_name,bool with_res)
 				}
 
 				++loop;
-			}				
+			}
 
 		}
 
@@ -1073,19 +1065,19 @@ int delete_server(char *d_name,bool with_res)
 	}
 	catch (Tango::DevFailed &e)
 	{
-		ret = -1;
+    return -1;
 	}
 
-	return ret;
+	return 0;
 }
 
 //+-------------------------------------------------------------------------
 //
 // method : 		add_property
-// 
+//
 // description : 	This function adds a device property in the DB
 //
-// argument : in : 	- d_name : The device name 
+// argument : in : 	- d_name : The device name
 //					- p_name : The property name
 //					- p_val : The property value
 //
@@ -1095,31 +1087,21 @@ int delete_server(char *d_name,bool with_res)
 
 int add_property(char *d_name,char *p_name,char *p_val)
 {
-	int ret = 0;
-
 //
 // Check dev name syntax
 //
 
-	string dev_name(d_name);
-	string::size_type pos1,pos2;
+	std::string dev_name(d_name);
+	std::string::size_type pos1,pos2;
 
 	pos1 = dev_name.find('/');
 	pos2 = dev_name.rfind('/');
-	
-#ifdef  __SUNPRO_CC
-	int n1 = 0;
-	count(dev_name.begin(),dev_name.end(),'/',n1);
-	if ((n1 != 2) || pos1 == 0 || pos2 == (dev_name.size() - 1) || pos2 == pos1 + 1)
-	{
-#else
-	if ((count(dev_name.begin(),dev_name.end(),'/') != 2) || 
+
+	if ((count(dev_name.begin(),dev_name.end(),'/') != 2) ||
 		pos1 == 0 || pos2 == (dev_name.size() - 1) || pos2 == pos1 + 1)
 	{
-#endif
-		cout << "Wrong syntax for device name" << endl;
-		ret = -1;
-		return ret;
+		std::cerr << "Wrong syntax for device name" << std::endl;
+    return -1;
 	}
 
 //
@@ -1133,8 +1115,8 @@ int add_property(char *d_name,char *p_name,char *p_val)
 // Convert prop value(s) into a vector
 //
 
-	string prop_val(p_val);
-	vector<string> prop_val_list;
+	std::string prop_val(p_val);
+	std::vector<std::string> prop_val_list;
 
 	list2vect(prop_val,prop_val_list);
 
@@ -1149,7 +1131,7 @@ int add_property(char *d_name,char *p_name,char *p_val)
 
 		Tango::DbData dbd;
 		Tango::DbDatum db_s(p_name);
-		
+
 		db_s << prop_val_list;
 		dbd.push_back(db_s);
 
@@ -1157,18 +1139,19 @@ int add_property(char *d_name,char *p_name,char *p_val)
 	}
 	catch (Tango::DevFailed &e)
 	{
-		ret = -1;
+    return -1;
 	}
-	return ret;
+
+  return 0;
 }
 
 //+-------------------------------------------------------------------------
 //
 // method : 		delete_property
-// 
+//
 // description : 	This function deletes a device property from the DB
 //
-// argument : in : 	- d_name : The device name 
+// argument : in : 	- d_name : The device name
 //					- p_name : The property name
 //
 // The function returns 0 is everything is fine. Otherwise, it returns -1
@@ -1177,31 +1160,21 @@ int add_property(char *d_name,char *p_name,char *p_val)
 
 int delete_property(char *d_name,char *p_name)
 {
-	int ret = 0;
-
 //
 // Check dev name syntax
 //
 
-	string dev_name(d_name);
-	string::size_type pos1,pos2;
+	std::string dev_name(d_name);
+	std::string::size_type pos1,pos2;
 
 	pos1 = dev_name.find('/');
 	pos2 = dev_name.rfind('/');
-	
-#ifdef  __SUNPRO_CC
-	int n1 = 0;
-	count(dev_name.begin(),dev_name.end(),'/',n1);
-	if ((n1 != 2) || pos2 == (dev_name.size() - 1) || pos2 == pos1 + 1)
-	{
-#else
-	if ((count(dev_name.begin(),dev_name.end(),'/') != 2) || 
+
+	if ((count(dev_name.begin(),dev_name.end(),'/') != 2) ||
 		pos1 == 0 || pos2 == (dev_name.size() - 1) || pos2 == pos1 + 1)
 	{
-#endif
-		cout << "Wrong syntax for device name" << endl;
-		ret = -1;
-		return ret;
+		std::cerr << "Wrong syntax for device name" << std::endl;
+    return -1;
 	}
 
 //
@@ -1227,15 +1200,16 @@ int delete_property(char *d_name,char *p_name)
 	}
 	catch (Tango::DevFailed &e)
 	{
-		ret = -1;
+    return -1;
 	}
-	return ret;
+
+  return 0;
 }
 
 //+-------------------------------------------------------------------------
 //
 // method : 		list2vect
-// 
+//
 // description : 	This function converts a comma separated
 //					device list into a vector of strings with one
 //					element for each device
@@ -1245,9 +1219,9 @@ int delete_property(char *d_name,char *p_name)
 //
 //--------------------------------------------------------------------------
 
-void list2vect(string &dev_list,vector<string> &dev_names)
+void list2vect(std::string &dev_list,std::vector<std::string> &dev_names)
 {
-	string::size_type beg,end;
+	std::string::size_type beg,end;
 
 	bool end_loop = false;
 	beg = 0;
@@ -1261,13 +1235,13 @@ void list2vect(string &dev_list,vector<string> &dev_names)
 			continue;
 		}
 
-		if (end == string::npos)
+		if (end == std::string::npos)
 		{
 			end = dev_list.length();
 			end_loop = true;
 		}
 
-		string one_dev;
+		std::string one_dev;
 		one_dev = dev_list.substr(beg,end - beg);
 		dev_names.push_back(one_dev);
 
@@ -1280,7 +1254,7 @@ void list2vect(string &dev_list,vector<string> &dev_names)
 //+-------------------------------------------------------------------------
 //
 // method : 		ping_network
-// 
+//
 // description : 	This function periodically chechs the network avaibility
 //
 // argument : in : 	- nb_sec : Max time (in sec) to do re-try in case of failure
@@ -1292,8 +1266,6 @@ void list2vect(string &dev_list,vector<string> &dev_names)
 
 int ping_network(int nb_sec,bool verbose)
 {
-	int ret = 0;
-
 	int nb_loop;
 	bool infinite = false;
 
@@ -1321,27 +1293,23 @@ int ping_network(int nb_sec,bool verbose)
 		int res = check_net(verbose);
 		if (res == 0)
 		{
-			ret = 0;
-			nb_loop = 0;
+      return 0;
 		}
-		else
-		{
-			ret = -1;
-			if (infinite == false)
+
+    if (infinite == false)
 				--nb_loop;
-		}
 
 		if (nb_loop != 0)
 			nanosleep(&ts,NULL);
 	}
 
-	return ret;	
+	return -1;
 }
 
 //+-------------------------------------------------------------------------
 //
 // method : 		check_net
-// 
+//
 // description : 	This function connect to the network and check if it is
 //					fully ready.
 //
@@ -1353,16 +1321,14 @@ int ping_network(int nb_sec,bool verbose)
 
 int check_net(bool verbose)
 {
-	int ret = 0;
-
 	char buffer[80];
-	string hostname;
+	std::string hostname;
 
 	if (gethostname(buffer,80) == 0)
 	{
 		hostname = buffer;
 		if (verbose == true)
-			cout << "Host name returned by gethostname function: " << hostname << endl;
+			std::cout << "Host name returned by gethostname function: " << hostname << std::endl;
 
   		struct addrinfo hints;
 
@@ -1384,18 +1350,17 @@ int check_net(bool verbose)
 		{
 			ptr = info;
 			if (verbose == true)
-				cout << "getaddrinfo() is a success" << endl;
+				std::cout << "getaddrinfo() is a success" << std::endl;
 			while (ptr != NULL)
 			{
     			if (getnameinfo(ptr->ai_addr,ptr->ai_addrlen,tmp_host,512,0,0,0) != 0)
 				{
 					if (verbose == true)
-						cout << "getnameinfo() call failed" << endl;
-					ret = -1;
-					break;
+						std::cout << "getnameinfo() call failed" << std::endl;
+          return -1;
 				}
 				if (verbose == true)
-					cout << "Host name as returned by getnameinfo call: " << tmp_host << endl;
+					std::cout << "Host name as returned by getnameinfo call: " << tmp_host << std::endl;
 				ptr = ptr->ai_next;
 			}
 
@@ -1404,24 +1369,24 @@ int check_net(bool verbose)
 		else
 		{
 			if (verbose == true)
-				cout << "getaddrinfo() call failed with returned value = " << result << endl;
-			ret = -1;
+				std::cout << "getaddrinfo() call failed with returned value = " << result << std::endl;
+
+      return -1;
 		}
 	}
 	else
 	{
-		cout << "Cant retrieve server host name" << endl;
-		ret = -1;
+		std::cerr << "Cant retrieve server host name" << std::endl;
+    return -1;
 	}
 
-	return ret;
-
+	return 0;
 }
 
 //+-------------------------------------------------------------------------
 //
 // method : 		tac_enabled
-// 
+//
 // description : 	This function check in DB if the TAC is enabled
 //
 // The function returns 0 if the TAC is disabled. Otherwise, it returns 1
@@ -1430,97 +1395,73 @@ int check_net(bool verbose)
 
 int tac_enabled(void)
 {
-
-	int ret = 1;
-
 	setenv("SUPER_TANGO","true",1);
 
 	try
 	{
 		Tango::Database db;
 
-		string servicename("AccessControl");
-		string instname("tango");
+		std::string servicename("AccessControl");
+		std::string instname("tango");
 		Tango::DbDatum db_datum = db.get_services(servicename,instname);
-		vector<string> service_list;
+		std::vector<std::string> service_list;
 		db_datum >> service_list;
 
-		if (service_list.empty() == true)
-			ret = 0;
+    return !service_list.empty();
 	}
 	catch (Tango::DevFailed &e)
 	{
-		ret = 0;
+    return 0;
 	}
 
-	return ret;
+  return 1;
 }
 
 //+-------------------------------------------------------------------------
 //
 // method : 		ping_device
-// 
-// description : 	This function periodically chechs a device avaibility
 //
-// argument : in : 	- nb_sec : Max time (in sec) to do re-try in case of failure
+// description : 	This function periodically checks a device's avaibility
+//
+// argument : in : 	- timeout_in_s : Max time (in fractional seconds) to do re-try in case of failure
 //					- dev_name : The device name
 //
-// The function returns 0 is everything is fine. Otherwise, it returns -1
+// return:  0 on sucess
+//          -ETIMEDOUT if device did not respond within time out
+//          negative errno returned bycompute_loops_and_sleep_time
 //
 //--------------------------------------------------------------------------
-
-int ping_device(char *dev_name,int nb_sec)
+int ping_device(const std::string &dev_name, double timeout_in_s)
 {
-	int ret = 0;
+    unsigned int loops;
+    struct timespec sleep_time{};
+    auto err{compute_loops_and_sleep_time(timeout_in_s, loops, sleep_time)};
+    if(err != 0)
+    {
+        return err;
+    }
 
-	int nb_loop;
-	bool infinite = false;
+    const double sleep_time_in_s{(sleep_time.tv_sec * 1e9 + sleep_time.tv_nsec) / 1e9};
 
-	if (nb_sec == 0)
-		nb_loop = 1;
-	else if (nb_sec < 0)
-	{
-		infinite = true;
-		nb_loop = 2;
-	}
-	else
-		nb_loop = nb_sec << 1;
+    while((loops > 0U) && (timeout_in_s > 0.0))
+    {
+        if(check_dev(dev_name.c_str()) == 0)
+        {
+            return 0;
+        }
 
-//
-// re-try the call every 500 mS
-//
+        nanosleep(&sleep_time, nullptr);
+        timeout_in_s -= sleep_time_in_s;
+        --loops;
+    };
 
-	struct timespec ts;
-	ts.tv_sec = 0;
-	ts.tv_nsec = 500000000;
-
-	while(nb_loop > 0)
-	{
-
-		int res = check_dev(dev_name);
-		if (res == 0)
-		{
-			ret = 0;
-			nb_loop = 0;
-		}
-		else
-		{
-			ret = -1;
-			if (infinite == false)
-				--nb_loop;
-		}
-
-		if (nb_loop != 0)
-			nanosleep(&ts,NULL);
-	}
-
-	return ret;	
+    return -ETIMEDOUT;
 }
 
 //+-------------------------------------------------------------------------
 //
 // method : 		check_dev
-// 
+//
 // description : 	This function connect to a device and try to ping it
 //
 // argument : in : 	- dev_name : The device name
@@ -1529,10 +1470,8 @@ int ping_device(char *dev_name,int nb_sec)
 //
 //--------------------------------------------------------------------------
 
-int check_dev(char *dev_name)
+int check_dev(const char *dev_name)
 {
-	int ret = 0;
-
 	try
 	{
 		Tango::DeviceProxy dev(dev_name);
@@ -1541,9 +1480,9 @@ int check_dev(char *dev_name)
 	}
 	catch (Tango::DevFailed &e)
 	{
-		ret = -1;
+		return -1;
 	}
 
-	return ret;
+	return 0;
 
 }
